==> imp-doc-2.1.0.tar.gz: html/classIMP_1_1multifit_1_1DensityDataPoints.js <==
var classIMP_1_1multifit_1_1DensityDataPoints =
[
    [ "DensityDataPoints", "classIMP_1_1multifit_1_1DensityDataPoints.html#a51782d49c5e98b159037c274f4e0e99c", null ],
    [ "DensityDataPoints", "classIMP_1_1multifit_1_1DensityDataPoints.html#aef54339a0d8c06ededf80addc49d46e2", null ],
    [ "get_type_name", "classIMP_1_1multifit_1_1DensityDataPoints.html#a453bf29b60a6feb2e5cae9614569031c", null ],
    [ "get_version_info", "classIMP_1_1multifit_1_1DensityDataPoints.html#a4acef994be7098ef06fae54f7a0d1ce5", null ],
    [ "populate_data", "classIMP_1_1multifit_1_1DensityDataPoints.html#a15ca4a605fee7b34441f1699f701a845", null ],
    [ "sample", "classIMP_1_1multifit_1_1DensityDataPoints.html#aee2926d7d3efa1d0469b3a0c6b6d55da", null ],
    [ "set_density", "classIMP_1_1multifit_1_1DensityDataPoints.html#ab0e076ff29e061cafed9b70b181b089c", null ],
    [ "set_density", "classIMP_1_1multifit_1_1DensityDataPoints.html#a7ee7bb1085f191fa2210ad31fb5ffa4c", null ],
    [ "set_max_min_density_values", "classIMP_1_1multifit_1_1DensityDataPoints.html#a468ce94846850582636ae77d3c022176", null ],
    [ "dens_", "classIMP_1_1multifit_1_1DensityDataPoints.html#a4c0ba4116c374db38fa557ea8141b5fd", null ],
    [ "max_value_", "classIMP_1_1multifit_1_1DensityDataPoints.html#a15af58a33484c2fa122c5612226f1b9d", null ],
    [ "min_value_", "classIMP_1_1multifit_1_1DensityDataPoints.html#aee4960612f7ff23cd2070baac16a588b", null ],
    [ "threshold_", "classIMP_1_1multifit_1_1DensityDataPoints.html#aec19d9352a2bcdbe8865011b78450968", null ]
];

==> imp-doc-2.3.1.tar.gz: html/classIMP_1_1multifit_1_1DensityDataPoints.js <==
var classIMP_1_1multifit_1_1DensityDataPoints =
[
    [ "DensityDataPoints", "classIMP_1_1multifit_1_1DensityDataPoints.html#a51782d49c5e98b159037c274f4e0e99c", null ],
    [ "DensityDataPoints", "classIMP_1_1multifit_1_1DensityDataPoints.html#aef54339a0d8c06ededf80addc49d46e2", null ],
    [ "~DensityDataPoints", "classIMP_1_1multifit_1_1DensityDataPoints.html#ad53d230c42325cb231d18fc0e8ce76c0", null ],
    [ "get_type_name", "classIMP_1_1multifit_1_1DensityDataPoints.html#a453bf29b60a6feb2e5cae9614569031c", null ],
    [ "get_version_info", "classIMP_1_1multifit_1_1DensityDataPoints.html#a4acef994be7098ef06fae54f7a0d1ce5", null ],
    [ "populate_data", "classIMP_1_1multifit_1_1DensityDataPoints.html#a15ca4a605fee7b34441f1699f701a845", null ],
    [ "sample", "classIMP_1_1multifit_1_1DensityDataPoints.html#aee2926d7d3efa1d0469b3a0c6b6d55da", null ],
    [ "set_density", "classIMP_1_1multifit_1_1DensityDataPoints.html#ab0e076ff29e061cafed9b70b181b089c", null ],
    [ "set_density", "classIMP_1_1multifit_1_1DensityDataPoints.html#a7ee7bb1085f191fa2210ad31fb5ffa4c", null ],
    [ "set_max_min_density_values", "classIMP_1_1multifit_1_1DensityDataPoints.html#a468ce94846850582636ae77d3c022176", null ],
    [ "dens_", "classIMP_1_1multifit_1_1DensityDataPoints.html#a4c0ba4116c374db38fa557ea8141b5fd", null ],
    [ "max_value_", "classIMP_1_1multifit_1_1DensityDataPoints.html#a15af58a33484c2fa122c5612226f1b9d", null ],
    [ "min_value_", "classIMP_1_1multifit_1_1DensityDataPoints.html#aee4960612f7ff23cd2070baac16a588b", null ],
    [ "threshold_", "classIMP_1_1multifit_1_1DensityDataPoints.html#aec19d9352a2bcdbe8865011b78450968", null ]
];
